==> qmmp_1.3.0.orig.tar.bz2: qmmp-1.3.0/src/plugins/General/rdetect/translations/rdetect_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Suplemento Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Sobre o suplemento Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Suplemento Qmmp Removable Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Este suplemento disponibiliza a deteção de volumes removidos</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Adicionar CD %1</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Adicionar volume %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Deteção de CD áudio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Adicionar faixas à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Remover faixas da lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Deteção de discos amovíveis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Adicionar ficheiros à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Remover ficheiros da lista de reprodução</translation>
    </message>
</context>
</TS>

==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/plugins/General/rdetect/translations/rdetect_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Suplemento Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>Acerca de suplemento Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Suplemento Qmmp Removable Volume Detection</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Este suplemento disponibiliza a deteção de volumes amovíveis</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Adicionar CD %1</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Adicionar volume %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Deteção de CD áudio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Adicionar faixas à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Remover faixas da lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Deteção de discos amovíveis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Adicionar ficheiros à lista de reprodução</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Remover ficheiros da lista de reprodução</translation>
    </message>
</context>
</TS>
